@@ -5,6 +5,7 @@ import re
 import tempfile
 from typing import Optional
 
+from .exceptions import ScrivException
 from .format import FormatTools, SectionDict
 from .shell import run_command
 
@@ -46,15 +47,26 @@ class RstTools(FormatTools):
         else:
             return False
 
+    def _is_anchor(self, line: str) -> bool:
+        """
+        Determine if a line is an anchor.
+        """
+        return bool(re.search(r"^.. _[-.\w]+:$", line))
+
     def parse_text(
         self, text: str
     ) -> SectionDict:  # noqa: D102 (inherited docstring)
         # Parse a very restricted subset of rst.
-        sections = {}  # type: SectionDict
-
         lines = text.splitlines()
+
+        # If there's an insert marker, start there.
+        for lineno, line in enumerate(lines):
+            if self.config.insert_marker in line:
+                lines = lines[lineno + 1 :]
+                break
         lines.append("")
 
+        sections: SectionDict = {}
         prev_line = ""
         paragraphs = None
         section_char = None
@@ -66,13 +78,16 @@ class RstTools(FormatTools):
                 # Comment, do nothing.
                 continue
 
+            if self._is_anchor(line):
+                continue
+
             if self._is_underline(line):
                 if section_char is None or line[0] == section_char:
                     # Section underline. Previous line was the heading.
-                    # General RST can have overlines as well as underlines, but
-                    # we only deal with underlines, so some paragraphs must have
-                    # preceded us.
-                    assert paragraphs is not None
+                    # General RST can have overlines as well as underlines,
+                    # which we detect because there are no previous paragraphs.
+                    if paragraphs is None or paragraphs[-1] == "":
+                        continue
                     # Heading was made a paragraph, undo that.
                     assert paragraphs[-1] == prev_line + "\n"
                     paragraphs.pop()
@@ -135,7 +150,7 @@ class RstTools(FormatTools):
         rst_file = None
         try:
             with tempfile.NamedTemporaryFile(
-                mode="w", prefix="scriv_rst_", delete=False,
+                mode="w", prefix="scriv_rst_", delete=False
             ) as rst_file:
                 rst_file.write(text)
                 rst_file.flush()
@@ -145,7 +160,9 @@ class RstTools(FormatTools):
                     + rst_file.name
                 )
                 if not ok:
-                    raise Exception(f"Couldn't convert ReST to Markdown: {output!r}")
+                    raise ScrivException(
+                        f"Couldn't convert ReST to Markdown: {output!r}"
+                    )
                 return output.replace("\r\n", "\n")
         finally:
             if rst_file is not None:
