@@ -13,7 +13,7 @@ from .github import create_release, get_releases, update_release
 from .gitinfo import get_github_repos
 from .scriv import Scriv
 from .shell import run_simple_command
-from .util import extract_version, is_prerelease_version
+from .util import Version
 
 logger = logging.getLogger(__name__)
 
@@ -63,60 +63,61 @@ def github_release(
     if not re.fullmatch(r"[^ /]+/[^ /]+", repo):
         sys.exit(f"Repo must be owner/reponame: {repo!r}")
 
-    tags = set(run_simple_command("git tag").split())
-    releases = get_releases(repo)
+    tags = set(map(Version, run_simple_command("git tag").split()))
+    releases = {Version(k): v for k, v in get_releases(repo).items()}
 
     for title, sections in changelog.entries().items():
         if title is None:
             continue
-        version = extract_version(title)
+        version = Version.from_text(title)
         if version is None:
             logger.warning(f"Entry {title!r} has no version, skipping.")
             continue
 
-        if version in tags:
-            section_text = "\n\n".join(sections)
-            md = changelog.format_tools().convert_to_markdown(section_text)
-
-            release_data = {
-                "body": md,
-                "name": version,
-                "tag_name": version,
-                "draft": False,
-                "prerelease": is_prerelease_version(version),
-            }
-
-            ghrel_template = jinja2.Template(scriv.config.ghrel_template)
-            md = ghrel_template.render(
-                body=md,
-                version=version,
-                release=release_data,
-                config=scriv.config,
-            )
-            release_data["body"] = md
-
-            if version in releases:
-                release = releases[version]
-                if release["body"] != md:
-                    logger.debug(
-                        f"Updating release {version}, data = {release_data}"
-                    )
-                    if dry_run:
-                        logger.info(f"Would update release {version}")
-                        logger.info(f"Body:\n{md}")
-                    else:
-                        update_release(release, release_data)
-            else:
-                logger.debug(f"Creating release, data = {release_data}")
-                if dry_run:
-                    logger.info(f"Would create release {version}")
-                    logger.info(f"Body:\n{md}")
-                else:
-                    create_release(repo, release_data)
-        else:
+        if version not in tags:
             logger.warning(
                 f"Version {version} has no tag. No release will be made."
             )
+            continue
+
+        section_text = "\n\n".join(sections)
+        md = changelog.format_tools().convert_to_markdown(section_text)
+
+        release_data = {
+            "body": md,
+            "name": str(version),
+            "tag_name": str(version),
+            "draft": False,
+            "prerelease": version.is_prerelease(),
+        }
+
+        ghrel_template = jinja2.Template(scriv.config.ghrel_template)
+        md = ghrel_template.render(
+            body=md,
+            version=version,
+            release=release_data,
+            config=scriv.config,
+        )
+        release_data["body"] = md
+
+        if version in releases:
+            release = releases[version]
+            if release["body"] != md:
+                logger.debug(
+                    f"Updating release {version}, data = {release_data}"
+                )
+                if dry_run:
+                    logger.info(f"Would update release {version}")
+                    logger.info(f"Body:\n{md}")
+                else:
+                    update_release(release, release_data)
+        else:
+            logger.debug(f"Creating release, data = {release_data}")
+            if dry_run:
+                logger.info(f"Would create release {version}")
+                logger.info(f"Body:\n{md}")
+            else:
+                create_release(repo, release_data)
 
         if not all_entries:
             break
