@@ -3,6 +3,7 @@ Find literals in various kinds of files.
 """
 
 import ast
+import configparser
 import os.path
 from typing import Any, MutableMapping, Optional
 
@@ -43,6 +44,10 @@ def find_literal(file_name: str, literal_name: str) -> Optional[str]:
         with open(file_name, encoding="utf-8") as f:
             data = yaml.safe_load(f)
         return find_nested_value(data, literal_name)
+    elif ext == ".cfg":
+        cfg_parser = configparser.ConfigParser()
+        cfg_parser.read(file_name)
+        return find_nested_value(cfg_parser, literal_name)
     else:
         raise ScrivException(
             f"Can't read literals from files like {file_name!r}"
