@@ -19,8 +19,13 @@ class FakeRunCommand:
     def __init__(self, mocker):
         """Make the faker."""
         self.handlers: Dict[str, CmdHandler] = {}
-        mocker.patch("scriv.gitinfo.run_command", self)
-        mocker.patch("scriv.shell.run_command", self)
+        self.mocker = mocker
+        self.patch_module("scriv.gitinfo")
+        self.patch_module("scriv.shell")
+
+    def patch_module(self, mod_name: str) -> None:
+        """Replace ``run_command`` in `mod_name` with our fake."""
+        self.mocker.patch(f"{mod_name}.run_command", self)
 
     def add_handler(self, argv0: str, handler: CmdHandler) -> None:
         """
@@ -34,10 +39,7 @@ class FakeRunCommand:
 
     def __call__(self, cmd: str) -> CmdResult:
         """Do the faking!."""
-        if isinstance(cmd, str):
-            argv = shlex.split(cmd)
-        else:
-            argv = cmd
+        argv = shlex.split(cmd)
         if argv[0] in self.handlers:
             return self.handlers[argv[0]](argv)
         return (False, f"no fake command handler: {argv}")
@@ -82,7 +84,6 @@ class FakeGit:
                 out.append(f"{name}\t{url} (fetch)\n")
                 out.append(f"{name}\t{push_url} (push)\n")
             return (True, "".join(out))
-        # raise Exception(f"no fake git command: {argv}")
         return (False, f"no fake git command: {argv}")
 
     def set_config(self, name: str, value: str) -> None:
@@ -106,3 +107,7 @@ class FakeGit:
     ) -> None:
         """Add a remote with a name and a url."""
         self.remotes[name] = (url, push_url or url)
+
+    def remove_remote(self, name: str) -> None:
+        """Remove the remote `name`."""
+        del self.remotes[name]
