@@ -2,7 +2,7 @@
 
 import re
 
-from scriv.gitinfo import current_branch_name, get_github_repo, user_nick
+from scriv.gitinfo import current_branch_name, get_github_repos, user_nick
 
 
 def test_user_nick_from_github(fake_git):
@@ -32,43 +32,44 @@ def test_current_branch_name(fake_git):
     assert current_branch_name() == "joedev/feature-123"
 
 
-def test_get_github_repo_no_remotes(fake_git):
-    assert get_github_repo() is None
+def test_get_github_repos_no_remotes(fake_git):
+    assert get_github_repos() == set()
 
 
-def test_get_github_repo_one_github_remote(fake_git):
+def test_get_github_repos_one_github_remote(fake_git):
     fake_git.add_remote("mygithub", "git@github.com:joe/myproject.git")
-    assert get_github_repo() == "joe/myproject"
+    assert get_github_repos() == {"joe/myproject"}
 
 
-def test_get_github_repo_one_github_remote_no_extension(fake_git):
+def test_get_github_repos_one_github_remote_no_extension(fake_git):
     fake_git.add_remote("mygithub", "git@github.com:joe/myproject")
-    assert get_github_repo() == "joe/myproject"
+    assert get_github_repos() == {"joe/myproject"}
 
 
-def test_get_github_repo_two_github_remotes(fake_git):
+def test_get_github_repos_two_github_remotes(fake_git):
     fake_git.add_remote("mygithub", "git@github.com:joe/myproject.git")
     fake_git.add_remote("upstream", "git@github.com:psf/myproject.git")
-    assert get_github_repo() is None
+    assert get_github_repos() == {"joe/myproject", "psf/myproject"}
 
 
-def test_get_github_repo_one_github_plus_others(fake_git):
+def test_get_github_repos_one_github_plus_others(fake_git):
     fake_git.add_remote("mygithub", "git@github.com:joe/myproject.git")
     fake_git.add_remote("upstream", "git@gitlab.com:psf/myproject.git")
-    assert get_github_repo() == "joe/myproject"
+    assert get_github_repos() == {"joe/myproject"}
 
 
-def test_get_github_repo_no_github_remotes(fake_git):
+def test_get_github_repos_no_github_remotes(fake_git):
     fake_git.add_remote("mygitlab", "git@gitlab.com:joe/myproject.git")
     fake_git.add_remote("upstream", "git@gitlab.com:psf/myproject.git")
-    assert get_github_repo() is None
+    assert get_github_repos() == set()
 
 
-def test_real_get_github_repo():
+def test_real_get_github_repos():
     # Since we don't know the name of this repo (forks could be anything),
     # we can't be sure what we get, except it should be word/word, and not end
     # with .git
-    repo = get_github_repo()
-    assert repo is not None
+    repos = get_github_repos()
+    assert len(repos) == 1
+    repo = repos.pop()
     assert re.fullmatch(r"\w+/\w+", repo)
     assert not repo.endswith(".git")
